#
# spec file for package python-django-extra-views
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-django-extra-views
Version:        0.15.0
Release:        2.1
Summary:        Extra class-based views for Django
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/AndrewIngram/django-extra-views
# not tagged on GitHub, downloaded via _service
Source:         django-extra-views-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/AndrewIngram/django-extra-views/pull/272 make tests compatible with Django 5.2
Patch:          django52.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module pytest-django}
# /SECTION
%python_subpackages

%description
Extra class-based views for Django.

%prep
%autosetup -p1 -n django-extra-views-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=extra_views_tests.settings
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*extra[-_]views*/

%changelog
* Tue Jun  3 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Tue Apr 22 2025 mmachova@suse.com
- Update to version 0.15.0:
  * Add Django 5.1, remove Python 3.5, Release 0.15.0 (#269)
  * Added support for Python 3.12, Django 5.0. (#267)
  * Added readthedocs.yaml configuration file. (#263)
  * Added .pre-commit-config.yaml and `Contributing` docs section. (#264)
  * chore: Add support for 4.2 (#262)
  * Added Python 3.11, run tests on ubuntu-20.04
  * add requires_python
  * Reformat docs/conf.py for latest version of black.
- Drop merged patches:
  * merged_10881330.patch
  * merged_pr_233.patch
- Add django52.patch making the testsuite compatible with Django 5.2
- Convert to _service workflow since the new release is not tagged
* Tue Nov 22 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six module
- Remove python_module macro definition
- Use autosetup instead of setup+patch
* Mon Jan 10 2022 John Vandenberg <jayvdb@gmail.com>
- Add merged_10881330.patch for Django 4.0 support
* Sat Jul 24 2021 John Vandenberg <jayvdb@gmail.com>
- Added merged_pr_233.patch for Django 3.2 support
- Update to v0.14.0
  * Removed support for Python 2.7.
  * Added support for Python 3.8 and Django 3.1.
  * Removed the following classes (use the class in parentheses instead):
    + BaseFormSetMixin (use BaseFormSetFactory)
    + BaseInlineFormSetMixin (use BaseInlineFormSetFactory)
    + InlineFormSet (use InlineFormSetFactory)
    + BaseGenericInlineFormSetMixin (use BaseGenericInlineFormSetFactory)
    + GenericInlineFormSet (use GenericInlineFormSetFactory)
* Fri Jun 26 2020 John Vandenberg <jayvdb@gmail.com>
- Activated test suite
* Thu May  7 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.13.0
* Fri Apr 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.12.0
